@@ -1,13 +1,13 @@
 /*
-Leaflet building and linting scripts.
+Leaflet building, testing and linting scripts.
 
 To use, install Node, then run the following commands in the project root:
 
     npm install -g jake
-    npm install uglify-js
-    npm install jshint
+    npm install
 
-To check the code and build Leaflet from source, run "jake"
+To check the code for errors and build Leaflet from source, run "jake".
+To run the tests, run "jake test".
 
 For a custom build, open build/build.html in the browser and follow the instructions.
 */
@@ -20,4 +20,7 @@ task('lint', build.lint);
 desc('Combine and compress Leaflet source files');
 task('build', ['lint'], build.build);
 
+desc('Run PhantomJS tests');
+task('test', ['lint'], build.test);
+
 task('default', ['build']);
